hierarc.Diagnostics package
===========================

Submodules
----------

hierarc.Diagnostics.goodness\_of\_fit module
--------------------------------------------

.. automodule:: hierarc.Diagnostics.goodness_of_fit
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hierarc.Diagnostics
   :members:
   :undoc-members:
   :show-inheritance:
